# Generated by Django 2.2.5 on 2020-09-02 20:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shortlink', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='shortlink',
            options={'verbose_name': 'Shortlink'},
        ),
        migrations.RemoveField(
            model_name='shortlink',
            name='long_url',
        ),
        migrations.RemoveField(
            model_name='shortlink',
            name='short_url',
        ),
        migrations.AddField(
            model_name='shortlink',
            name='full_url',
            field=models.CharField(default='', max_length=500, verbose_name='Real URL to be shorten'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='shortlink',
            name='short_path',
            field=models.CharField(db_index=True, default='', max_length=100, verbose_name='Shorten Path ID'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='shortlink',
            name='name',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Presentation name for url'),
        ),
        migrations.AlterModelTable(
            name='shortlink',
            table='shortlink',
        ),
    ]



from django.db import models
from django.utils.translation import ugettext_lazy as _

from .settings import *
from .utils import generate_random_str


class ShortLink(models.Model):
    name = models.CharField(
        max_length=100,
        null=True, blank=True,
        verbose_name=_('Presentation name for url')
    )   # If not set, will be set to full_url
    short_path = models.CharField(
        db_index=True,
        max_length=100,
        null=True, blank=True,
        verbose_name=_('Shorten Path ID'),
        help_text=_('If not provided, will generate automatically')
    )   # Should be db_index ed.
    full_url = models.CharField(
        max_length=500,
        verbose_name=_('Real URL to be shorten')
    )

    def __str__(self):
        return '{}-{}'.format(self.pk, self.name)

    class Meta:
        db_table = 'shortlink'
        verbose_name = 'Shortlink'
        verbose_name_plural = _('Shortlink')

    @property
    def short_url(self):
        """ Complete short url
        Pattern:
            short_url = HOST_ADDRESS + '/' +  SHORTLINK_URL_BASE + shorten_path
        """
        return '{}/{}{}'.format(
            HOST_ADDRESS,
            SHORTLINK_URL_BASE,
            self.short_path
        )

    def save(self, force_insert=False, force_update=False, using=None, update_fields=None):
        if not self.short_path:
            self.generate_short_path(commit=False)
            # Don't save cause will call save() later.

        if not self.name:
            self.name = self.full_url
        super(ShortLink, self).save()

    def generate_short_path(self, commit=True):
        # Loop until a not used path found!
        while True:
            path = generate_random_str(SHORTEN_PATH_LENGTH)
            if not ShortLink.objects.filter(short_path=path).exists():
                break
        self.short_path = path
        if commit:
            self.save()



# Generated by Django 2.2.4 on 2020-09-16 22:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shortlink', '0002_auto_20200902_2012'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='shortlink',
            options={'verbose_name': 'Shortlink', 'verbose_name_plural': 'کوتاه\u200cکننده لینک'},
        ),
        migrations.AlterField(
            model_name='shortlink',
            name='full_url',
            field=models.CharField(max_length=500, verbose_name='آدرس URL اصلی برای کوتاه\u200cسازی'),
        ),
        migrations.AlterField(
            model_name='shortlink',
            name='name',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='نام url'),
        ),
        migrations.AlterField(
            model_name='shortlink',
            name='short_path',
            field=models.CharField(db_index=True, max_length=100, verbose_name='مسیر کوتاه شده'),
        ),
    ]



import string
import random


def generate_random_str(num=4):
    return ''.join(random.SystemRandom().choice(
        string.ascii_uppercase +
        string.ascii_lowercase +
        string.digits
    ) for _ in range(num))



# Generated by Django 2.2.4 on 2020-09-17 17:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shortlink', '0004_auto_20200916_2242'),
    ]

    operations = [
        migrations.AlterField(
            model_name='shortlink',
            name='short_path',
            field=models.CharField(blank=True, db_index=True, help_text='در صورتی که تعریف نشود\u200c، به صورت اتوماتیک ایجاد خواهد شد.', max_length=100, null=True, verbose_name='مسیر کوتاه شده'),
        ),
    ]



# Generated by Django 2.2.4 on 2020-09-16 22:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shortlink', '0003_auto_20200916_2241'),
    ]

    operations = [
        migrations.AlterField(
            model_name='shortlink',
            name='short_path',
            field=models.CharField(blank=True, db_index=True, help_text='If not provided, will generate automatically', max_length=100, null=True, verbose_name='مسیر کوتاه شده'),
        ),
    ]



from django.urls import re_path

from .views import map_link
from .settings import SHORTLINK_URL_BASE


urlpatterns = [
    re_path('^{}(?P<path>[a-zA-Z0-9 _-]+)$'.format(SHORTLINK_URL_BASE), map_link, name='map_link'),
]



from django.conf import settings


# Lenght of shortlinked path
SHORTEN_PATH_LENGTH = getattr(settings, 'SHORTEN_PATH_LENGTH', 8)

# Will indicate that all path starting with s/ is redirected to this app.
SHORTLINK_URL_BASE = getattr(settings, 'SHORTLINK_URL_BASE', 's/')

# This variable is used for generate short_link and send for users usages.
# For example a shortlink with identifier /abcd is created, now we want to
# get the full short-link-url and send it to client.
# So short_link = HOST_ADDRESS + '/' +  SHORTLINK_URL_BASE + shorten_path
HOST_ADDRESS = getattr(settings, 'HOST_ADDRESS', 'http://localhost:8000')



# Generated by Django 2.2.5 on 2020-10-08 16:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shortlink', '0005_auto_20200917_1707'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='shortlink',
            options={'verbose_name': 'Shortlink', 'verbose_name_plural': 'Shortlink'},
        ),
        migrations.AlterField(
            model_name='shortlink',
            name='full_url',
            field=models.CharField(max_length=500, verbose_name='Real URL to be shorten'),
        ),
        migrations.AlterField(
            model_name='shortlink',
            name='name',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Presentation name for url'),
        ),
        migrations.AlterField(
            model_name='shortlink',
            name='short_path',
            field=models.CharField(blank=True, db_index=True, help_text='If not provided, will generate automatically', max_length=100, null=True, verbose_name='Shorten Path ID'),
        ),
    ]



import os
from setuptools import setup

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.md')).read()

setup(
    name='django-shortlink',
    version='0.0.8',
    packages=['shortlink'],
    description='A simple Django App to hold short links mapped to long urls used in your projects.',
    long_description=README,
    long_description_content_type='text/markdown',
    author='Execut3',
    author_email='execut3.binarycodes@gmail.com',
    url='https://github.com/Execut3/django-shortlink',
    license='GPT',
    install_requires=[
        'Django>=2.0',
    ],
    include_package_data=True,
)



from django.http import (HttpResponseRedirect, Http404)

from .models import ShortLink


def map_link(request, **kwargs):
    path = kwargs.get('path', '')
    s = ShortLink.objects.filter(short_path=path).first()
    if s:
        return HttpResponseRedirect(s.full_url)
    raise Http404



from django.contrib import admin

from .models import ShortLink


@admin.register(ShortLink)
class ShortLinkAdmin(admin.ModelAdmin):
    search_fields = ['name', 'short_path', 'full_url']
    list_display = (
        'id', 'name', 'short_path', 'full_url',
    )
    list_per_page = 100
